# 说明文档
星门数据库是一款微型电脑数据库

官方首页:
http://www.stargatedb.com/

文档教程：
http://www.stargatedb.com/index.php/wendangjiaocheng.html

一、基本简介
支持python2.7或python3.5版本以上，轻便灵活
支持树莓派、STM32等开发平台
支持中英文字符定时存储
支持linux、windows、docker容器内（不占用端口）
支持多媒体数据存储

二、应用范围
物联网、机器人、智能硬件、工业自动化等领域

三、功能介绍：
1.中英文字符数据存储,支持生命周期
2.图像数据存储
3.音频数据存储
4.视频数据存储
5.附件存储

四、申请账号
账号级别  存储大小    
一级       1MB
二级       1G
三级       10G
四级       100G

申请账号网址：
http://www.stargatedb.com/index.php/page/user.html